---
hide:
  - navigation
---
# 4.0 Migration Guide

In this document we describe the steps that should be taken to migrate from `orchestrator-core` v3 to v4.

## About 4.0

In this release we have removed the caching of domain models. Domain models will always be loaded from the database.

## Steps

To use 4.0 all workflows must have run to completion. The `cache_domain_models` step no longer is part of the codebase
therfore `in flight` workflows will fail.
